package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0D```````````(`/@`!````,!]```````!``````````/C&````
M`````````$``.``(`$``&@`9``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````)2V````````E+8`````````
M`"````````$````&`````,``````````P&````````#`8```````-`0`````
M``"("0``````````(````````@````8````HP````````"C`8```````*,!@
M``````#P`0```````/`!````````"``````````$````!````!@"````````
M&`)````````8`D```````!@`````````&``````````$`````````%#E=&0$
M````6+(```````!8LD```````%BR0```````U`````````#4``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB97AE8R]L9"UE;&8N<V\N,0`````(````
M!`````$```!&<F5E0E-$`(B_#0!A````9````````````````````#@`````
M````*P```&$````B``````````````!,`````````%````!*`````````#,`
M```Z````7P````(````M````4P```%P````U````````````````````'0``
M`$D````D````4@`````````J````70```$L````+`````````%X```!@````
M)P```&,`````````.P````````!/````6````%$```!;```````````````&
M````'````!(````C````+P````H````W````/0```$$```!9`````````$(`
M```\`````````$X`````````````````````````5````"@````7````2```
M`"P````_`````````````````````P```!L````%````8@```%H```!`````
M`````!\````)````````````````````/@````````!5````#P````````!#
M````1````````````````````````````````0``````````````````````
M````````````````````````````````````````#0``````````````````
M```````````````````````````````````````````````````````:````
M````````````````&0````@````1````````````````````%`````P````.
M`````````!4````E`````````````````````````!@`````````````````
M`````````````````````````````"`````3````````````````````,```
M`````````````````"D`````````'@```!8````F````1P`````````R````
M`````"$```!-````+@```````````````````````````````````#0````V
M``````````0```!%````1@```!````!6```````````````Q````.0```%<`
M```'`````````````````````````````````````````'8!```2````````
M```````A`0```````)0#```2``P`P$]````````%`````````*4#```2``P`
M0"!````````T``````````P````2```````````````5``````````H$```2
M```````````````>`````````&0#```2``P`,!]```````"<`````````!8`
M```2``````````````!A!0```````'T"```2````````````````````````
M`"$````1`!<`0,1@```````!`````````"\"```2``````````````"L````
M`````#@````@`````````````````````````'("```1`!8`$,1@```````(
M`````````$P````2``T`-%-``````````````````+(#```2``P`T$]`````
M``#<`@```````,@#```2``P`P#=```````!-`````````-8#```2``P`\$Y`
M``````#)`````````%(````2```````````````[!````````%L````1`!<`
M4,1@```````!`````````&8````2``````````````#P`````````'0````2
M``````````````!"`````````.P#```2``P`P#]```````#B`````````/@#
M```2``P`D#]````````B`````````(0````1`!<`8,1@```````!````````
M`)(````2``````````````!A`0```````+D"```2```````````````O````
M`````.<"```2```````````````,`````````!,$```2``P`L$!```````!M
M`````````%$#```2```````````````/`````````/\"```2````````````
M`````````````$(#```2``````````````!L`````````*`````1`!<`<,1@
M```````(`````````"\#```2`````````````````````````*H````2````
M```````````K``````````T#```2```````````````"`````````+4````2
M```````````````*`P```````$H#```2``````````````!5`````````!X#
M```2``````````````#9`````````,,````1`!<`>,1@```````(````````
M`"8#```2``````````````"0`````````#D"```2``````````````!*````
M`````,D````2```````````````5`````````+,"```2``````````````!G
M`````````-<````1`!<`@,1@```````(`````````*0"```2````````````
M``#T`````````.0````2````!!U```````#.`0```````#0"```2````````
M``````!Q`````````/0````1`!<`B,1@```````!`````````/\````2````
M```````````/`0```````!`!```2``````````````"J!P```````"X#```2
M`````````````````````````!\!```1`!<`D,1@```````(`````````!<#
M```2`````````````````````````)8"```2````````````````````````
M`)`"```2`````````````````````````!\$```2``P`L%)````````4````
M`````)P"```2```````````````T`````````"\!```2``````````````"1
M`@```````#T!```2```````````````?&@```````,`"```2````````````
M`````````````/<"```2``````````````!,`````````-8"```2````````
M```````,`````````%\#```0`/'_-,1@`````````````````$L!```1`!<`
M@,E@```````(`````````%,!```2``````````````#D`````````&H"```2
M``````````````"/$````````#\"```2```````````````Q`````````*L"
M```2```````````````*`````````&,"```2``````````````!*````````
M`%\!```1`!<`F,1@```````(`````````"<$```2``P`$#A````````>````
M`````%$"```1`!<`H,1@``````!``````````#0#```2``````````````!\
M`````````&L#```0`/'_B,E@`````````````````,<"```2````````````
M``````````````8#```2``````````````!4`````````&H!```2````````
M```````V`````````'T!```2``````````````"0`````````(H!```1`!<`
MX,1@```````!`````````)<!```1`!<`\,1@```````3`````````+L"```2
M```````````````O`````````$,$```2``P`P$1````````L"@```````*8!
M```2``````````````"-`````````%@#```0`/'_-,1@````````````````
M`!$````2```````````````-!P```````+$!```2``````````````#%`@``
M`````%`$```2``P`L#Q````````7`0```````&($```2``P`$$-```````"L
M`0```````&\$```1`!8`*,1@```````(`````````+P!```2````````````
M``!G`````````,X"```2``````````````!*`````````.X"```2````````
M``````";`````````(8"```1`!<`(,5@```````(`````````#L#```2````
M``````````!^`````````'D$```2``P`T#U```````"^`0```````(8$```2
M``P`($%```````#P`0```````"$$```2``H`0!M``````````````````,L!
M```1`!<`*,5@```````(`````````-4!```2``````````````!\````````
M`.P!```2``````````````"="`````````!L:6)P97)L+G-O`'!E<FQ?9G)E
M90!P97)L7W!A<G-E`%!,7W!E<FQ?9&5S=')U8W1?;&5V96P`7TIV7U)E9VES
M=&5R0VQA<W-E<P!?9FEN:0!P97)L7W)U;@!03%]I;E]E=F%L`%!E<FQ?879?
M<VAI9G0`4&5R;%]G=E]F971C:'!V`%!,7V5X:71?9FQA9W,`4&5R;%]S=E]S
M971P=@!03%]C;VUP8W8`<&5R;%]A;&QO8P!097)L7V1O=6YW:6YD`%!,7V]P
M`%!E<FQ?<WES7W1E<FT`4$Q?979A;%]R;V]T`&)O;W1?1'EN84QO861E<@!0
M3%]T86EN=&5D`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]C;VYS=')U8W0`4$Q?
M8W5R<W1A8VMI;F9O`%!E<FQ?879?9F5T8V@`<&5R;%]D97-T<G5C=`!E;G9I
M<F]N`%!E<FQ?;6=?<V5T`%!,7W1O<%]E;G8`4&5R;%]S869E<WES;6%L;&]C
M`%!E<FQ?;F5W4U9P=@!03%]D;U]U;F1U;7``4$Q?;65M;W)Y7W=R87``4&5R
M;%]C<F]A:P!097)L7VYE=UA3`%!E<FQ?<WES7VEN:70S`%!,7W!A<G-E<@!0
M97)L7W-A=F5?9&5S=')U8W1O<E]X`%!E<FQ?<W9?,G!V7V9L86=S`&QI8FTN
M<V\N-0!L:6)C<GEP="YS;RXU`&QI8G5T:6PN<V\N.0!L:6)T:'(N<V\N,P!O
M<&5N`')E860`8VQO<V4`7U]E<G)O<@!L:6)C+G-O+C<`7U]S=&%C:U]C:&M?
M9W5A<F0`;65M8W!Y`')E86QL;V,`7U]P<F]G;F%M90!R96%D;&EN:P!?7W-T
M9&5R<G``<FUD:7(`;6MD:7(`<W1R;F-M<`!S=')L96X`;W!E;F1I<@!L<V5E
M:P!A=&5X:70`86-C97-S`&=E='!I9`!M96UM;W9E`%]?<W1A8VM?8VAK7V9A
M:6P`<W1R=&]K`&-L;W-E9&ER`'-T<FYC<'D`=6YL:6YK`&UE;7-E=`!?:6YI
M=%]T;',`9V5T=6ED`&9P<FEN=&8`<W!R:6YT9@!L<W1A=`!S=')S='(`<W1R
M8VUP`')E861D:7(`<W1R9'5P`&5X96-V<`!?961A=&$`7U]B<W-?<W1A<G0`
M7V5N9``O=7-R+VQO8V%L+VQI8B]P97)L-2\U+C$T+VUA8V@O0T]210!P87)?
M8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/
M3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I
M<FYA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``
M>'-?:6YI=`!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`<&%R7VUK=&UP
M9&ER`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`
M<&%R7VEN:71?96YV`&UA:6X`1D)31%\Q+C`````"``$``0````(``0````(`
M```#`````0`!``$``0`!`````````````0`!```````"``(``0`"``(``@``
M``(````"`````@`"`````@`#`````@````(````#``````````(````"``(`
M`@`!``(```````(``@`"``$``0````(``P`"``(````!``(``@`!``(``@``
M``````````(``0````$``@````$``0`!`````@`"``(``@`!``$``0``````
M`````````0`!`","```0````(````+`H>@<```,`BP0````````!``$`1P(`
M`!``````````L"AZ!P```@"+!````````$#$8```````!0````D`````````
M`````%#$8```````!0```!(``````````````&#$8```````!0```!<`````
M`````````'#$8```````!0```!\``````````````'C$8```````!0```"8`
M`````````````(#$8```````!0```"L``````````````(C$8```````!0``
M`"\``````````````)#$8```````!0```#,``````````````)C$8```````
M!0```$4``````````````*#$8```````!0```$<``````````````.#$8```
M````!0```$X``````````````/#$8```````!0```$\``````````````"#%
M8```````!0```%P``````````````"C%8```````!0```&$`````````````
M`##"8```````!P````$``````````````#C"8```````!P````0`````````
M`````$#"8```````!P````4``````````````$C"8```````!P````<`````
M`````````%#"8```````!P````@``````````````%C"8```````!P````H`
M`````````````&#"8```````!P```!$``````````````&C"8```````!P``
M`!,``````````````'#"8```````!P```!0``````````````'C"8```````
M!P```!@``````````````(#"8```````!P```!D``````````````(C"8```
M````!P```!H``````````````)#"8```````!P```!P``````````````)C"
M8```````!P```!T``````````````*#"8```````!P```!X`````````````
M`*C"8```````!P```"```````````````+#"8```````!P```"$`````````
M`````+C"8```````!P```"(``````````````,#"8```````!P```",`````
M`````````,C"8```````!P```"0``````````````-#"8```````!P```"4`
M`````````````-C"8```````!P```"<``````````````.#"8```````!P``
M`"@``````````````.C"8```````!P```"D``````````````/#"8```````
M!P```"H``````````````/C"8```````!P```"P```````````````##8```
M````!P```"T```````````````C#8```````!P```"X``````````````!##
M8```````!P```#```````````````!C#8```````!P```#$`````````````
M`"##8```````!P```#(``````````````"C#8```````!P```#0`````````
M`````###8```````!P```#4``````````````#C#8```````!P```#8`````
M`````````$##8```````!P```#@``````````````$C#8```````!P```#D`
M`````````````%##8```````!P```#H``````````````%C#8```````!P``
M`#L``````````````&##8```````!P```#P``````````````&C#8```````
M!P```#T``````````````'##8```````!P```$```````````````'C#8```
M````!P```$$``````````````(##8```````!P```$(``````````````(C#
M8```````!P```$,``````````````)##8```````!P```$0`````````````
M`)C#8```````!P```$@``````````````*##8```````!P```$H`````````
M`````*C#8```````!P```$L``````````````+##8```````!P```$P`````
M`````````+C#8```````!P```$T``````````````,##8```````!P```%``
M`````````````,C#8```````!P```%(``````````````-##8```````!P``
M`%0``````````````-C#8```````!P```%4``````````````.##8```````
M!P```%D``````````````.C#8```````!P```%H``````````````/##8```
M````!P```%L``````````````/C#8```````!P```%T```````````````#$
M8```````!P```&(```````````````C$8```````!P```&,`````````````
M`$B#[`CHQP0``.BR-P``2(/$",,`_S7&IB``_R7(IB``#Q]``/\EQJ8@`&@`
M````Z>#_____);ZF(`!H`0```.G0_____R6VIB``:`(```#IP/____\EKJ8@
M`&@#````Z;#_____)::F(`!H!````.F@_____R6>IB``:`4```#ID/____\E
MEJ8@`&@&````Z8#_____)8ZF(`!H!P```.EP_____R6&IB``:`@```#I8/__
M__\E?J8@`&@)````Z5#_____)7:F(`!H"@```.E`_____R5NIB``:`L```#I
M,/____\E9J8@`&@,````Z2#_____)5ZF(`!H#0```.D0_____R56IB``:`X`
M``#I`/____\E3J8@`&@/````Z?#^____)4:F(`!H$````.G@_O___R4^IB``
M:!$```#IT/[___\E-J8@`&@2````Z<#^____)2ZF(`!H$P```.FP_O___R4F
MIB``:!0```#IH/[___\E'J8@`&@5````Z9#^____)1:F(`!H%@```.F`_O__
M_R4.IB``:!<```#I</[___\E!J8@`&@8````Z6#^____)?ZE(`!H&0```.E0
M_O___R7VI2``:!H```#I0/[___\E[J4@`&@;````Z3#^____)>:E(`!H'```
M`.D@_O___R7>I2``:!T```#I$/[___\EUJ4@`&@>````Z0#^____)<ZE(`!H
M'P```.GP_?___R7&I2``:"````#IX/W___\EOJ4@`&@A````Z=#]____);:E
M(`!H(@```.G`_?___R6NI2``:",```#IL/W___\EIJ4@`&@D````Z:#]____
M)9ZE(`!H)0```.F0_?___R66I2``:"8```#I@/W___\ECJ4@`&@G````Z7#]
M____)8:E(`!H*````.E@_?___R5^I2``:"D```#I4/W___\E=J4@`&@J````
MZ4#]____)6ZE(`!H*P```.DP_?___R5FI2``:"P```#I(/W___\E7J4@`&@M
M````Z1#]____)5:E(`!H+@```.D`_?___R5.I2``:"\```#I\/S___\E1J4@
M`&@P````Z>#\____)3ZE(`!H,0```.G0_/___R4VI2``:#(```#IP/S___\E
M+J4@`&@S````Z;#\____)2:E(`!H-````.F@_/___R4>I2``:#4```#ID/S_
M__\E%J4@`&@V````Z8#\____)0ZE(`!H-P```.EP_/___R4&I2``:#@```#I
M8/S___\E_J0@`&@Y````Z5#\____)?:D(`!H.@```.E`_/___R7NI"``:#L`
M``#I,/S__P```````````````%5(B>5!54R-;PA!5%-(@^P(BQ](8\.%VTR-
M9,<03(DE+*H@`'XZ2(M7"$B%TG0Q2(D5JJ0@``^V`H3`="-(@\(!/"](BP66
MI"``2`]$PDB)!8ND(``/M@)(@\(!A,!UX;@HP&``2(7`="M(B??H8OS__[\T
M4T``Z%C\___HC_O__XG?3(GB3(GNZ&(A``")Q^B__O__Z*K\___KUI"0D)"`
M/5FE(```54B)Y700ZR202(/`"$B)!36D(`#_TDB+!2RD(`!(BQ!(A=)UY,8%
M+:4@``')PP\?1```9@\?1```54B#/0>@(```2(GE=!:X`````$B%P'0,OR#`
M8`!)B</)0?_CR<.0D)"0D)"0D)"0#[8/2(GXA,ET*$B+!0<U``!(C5<!#[8P
M2(GX#Q]$``!`./$/M@I(#T3"2(/"`83)=>[SPV8/'T0``&8/'T0``$%62(UW
M.$%505152(G]4TB![`@"``!,C4PDB$V-@8````!,B<](BPY(@\8(2(G*2(G(
M2,'B"$C!X!@E````_X'B``#_`$@)PDB)R$C!Z`@E`/\``$@)PDB)R$C!Z!@E
M_P```$@)PDB)R$C!Z2A(P>@@2(D72,'@"$B)PDC!X!`E````_X'B``#_`$@)
MPDB)R$C!Z1`E`/\``$@)PD@)RDB)5PA(@\<03#G'#X5U____28U):$F-L6@"
M```/'T0``$B+`4@S0=A(,T&H2#-!F$B)PD@!P$C!ZA]("<*#XO](B5$82(/!
M"$@Y\7743(MU`$B+?"2(0;W<O!N/2`-]($B+30A,BU402(MU&$R)\$R)\DV)
M\4C!X@5(P>@;28G(2`G03(G22<'H`H/@_T@ARDG!Z0)(C;P'F7F"6DB)R$C!
MX1Y(]]!)"<A((?!!@^#_2`-T))!("=!,B<(!QTR)\$PA\DCWT$B)^4PAT$C!
MZ1M,`U0DF$@)PDB)^$C!X`5(C;06F7F"6DB)^D@)P4R)\$C!X!X!\4D)P4B)
M^$B)SD&#X?](]]!(P>X;3"'*3"'`2`G02(G*38V4`IEY@EI(B<A(P>`%2`G&
M2(G(1`'628GZ2/?02<'J`DC!YQY,`T0DH$D)^DPAR$B)]T&#XO](P>\;3`-,
M)*A,(=)("=!(B?)-C80`F7F"6DB)\$C!X`5("<=(B?!$`<=)B<A(P>$>2<'H
M`DCWT$D)R$PAT$B)^4&#X/](P>D;3`-4)+!,(<)("=!(B?I-C8P!F7F"6DB)
M^$C!X`5("<%(B?A$`<E)B?%(P>8>2<'I`DCWT$D)\4PAP$B)SD&#X?](P>X;
M3"'*2`G02(G*38V4`IEY@EI(B<A(P>`%3`-$)+A("<9(B<A$`=9)B?I(P><>
M2<'J`DCWT$D)^DPAR$B)]T&#XO](P>\;3`-,),!,(=)("=!(B?)-C80`F7F"
M6DB)\$C!X`5("<=(B?!$`<=)B<A(P>$>2<'H`DCWT$D)R$PAT$B)^4&#X/](
MP>D;3`-4),A,(<)("=!(B?I-C8P!F7F"6DB)^$C!X`5("<%(B?A$`<E)B?%(
MP>8>2<'I`DCWT$D)\4PAP$B)SD&#X?],(<I(P>X;3`-$)-!("=!(B<I-C90"
MF7F"6DB)R$C!X`5("<9(B<A$`=9)B?I(P><>2<'J`DCWT$D)^DPAR$B)]T&#
MXO](P>\;3`-,)-A,(=)("=!(B?)-C80`F7F"6DB)\$C!X`5("<=(B?!$`<=)
MB<A(P>$>2<'H`DCWT$D)R$PAT$B)^4&#X/](P>D;3"'"2`G02(GZ38V,`9EY
M@EI(B?A(P>`%2`G!2(GX1`')28GQ2,'F'DG!Z0)(]]!)"?%(B<Y!@^'_3`-4
M).!,(<!,(<I(P>X;3`-$).A("=!(B<I-C90"F7F"6DB)R$C!X`5("<9(B<A$
M`=9)B?I(P><>2<'J`DCWT$D)^DPAR$B)]T&#XO](P>\;3`-,)/!,(=)("=!(
MB?)-C80`F7F"6DB)\$C!X`5("<=(B?!$`<=)B<A(P>$>2<'H`DCWT$D)R$PA
MT$B)^4&#X/](P>D;3"'"2`G02(GZ38V,`9EY@EI(B?A(P>`%2`G!2(GX1`')
M28GQ2/?02<'I`DC!YAY,`U0D^$D)\4PAP$B)SD&#X?](P>X;3`,$)$PARD@)
MT$B)RDV-E`*9>8):2(G(2,'@!4@)QDB)R$0!UDF)^DC!YQY)P>H"2/?028GS
M20GZ3"'(2(GW08/B_TC![QM,`TPD"$PATD@)T$B)\DV-A`"9>8):2(GP2,'@
M!4@)QTB)\$0!QTF)R$C!X1Y)P>@"2/?020G(3"'02(GY08/@_TC!Z1M,(<)(
M"=!(B?I-C8P!F7F"6DB)^$C!X`5(P>8>2<'K`DP#5"002`G!20GS2(GX08/C
M_T0!R4CWT$PAVDB)SDPAP$F)^4C![AM("=!(P><>2<'I`DV-E`*9>8):2(G(
M3`-$)!A(P>`%20GY2(G*2`G&2(G(08/A_TCWT$PARD0!UDPAV$B)]TF)RD@)
MT$C!X1Y(P>\;38V$`)EY@EI(B?!)P>H"2,'@!4P#7"0@20G*2`G'2(GP08/B
M_TB)\DCWT$0!QTPAR$F)\$PATD@)T$C!YAY)P>@"38V<`YEY@EI)"?!(B?I(
MB?A!@^#_3`-,)"A(P>`%2,'J&T@)PDR)P$PQT$0!VDP#5"0P2#'X2(G138V,
M`:'KV6Y(B=!(P>D;2,'@!4@)P40!R4F)^4C!YQY)P>D"2(G.20GY2(G72,'N
M&T&#X?](P>\"3(G(3#'`3`-$)#A(,=!(P>(>38V4`J'KV6Y("==(B<B#Y_](
MP>`%2`G&2(GX1`'63#'(3`-,)$!(,<A(B?)-C80`H>O9;DB)\$C!ZAM(P>`%
M2`G"1`'"28G(2,'A'DG!Z`))"<A(B=%!@^#_2,'I&TR)P$@Q^$@#?"1(2#'P
M38V,`:'KV6Y(B=!(P>`%2`G!1`')28GQ2,'F'DG!Z0))"?%(B<Y!@^'_2,'N
M&TR)R$PQP$P#1"102#'02(V\!Z'KV6Y(B<A(P>`%2`G&`?Y(B==(P>(>2,'O
M`D@)UTB)\H/G_TB)^$PQR$C!ZAM,`TPD6$@QR$V-A`"AZ]EN2(GP2,'@!4@)
MPD0!PDF)R$C!X1Y)P>@"20G(2(G108/@_TC!Z1M,B<!(,?A(`WPD8$@Q\$V-
MC`&AZ]EN2(G02,'@!4@)P40!R4F)\4C!YAY)P>D"20GQ2(G.08/A_TC![AM,
MB<A,,<!,`T0D:$@QT$B-O`>AZ]EN2(G(2,'@!4@)Q@'^2(G72,'B'DC![P)(
M"==(B?*#Y_](B?A,,<A(P>H;3`-,)'!(,<A-C80`H>O9;DB)\$C!X`5("<)$
M`<))B<A(P>$>2<'H`DD)R$B)T4&#X/](P>D;3(G`2#'X2`-\)'A(,?!-C8P!
MH>O9;DB)T$C!X`5("<%$`<E)B?%(P>8>2<'I`DD)\4B)SD&#X?](P>X;3(G(
M3#'`3`.$)(````!(,=!(C;P'H>O9;DB)R$C!X`5("<8!_DB)UTC!XAY(P>\"
M2`G72(GR@^?_2(GX3#'(2,'J&TP#C"2(````2#'(38V$`*'KV6Y(B?!(P>`%
M2`G"1`'"28G(2,'A'DG!Z`))"<A(B=%!@^#_2,'I&TR)P$@Q^$@#O"20````
M2#'P38V,`:'KV6Y(B=!(P>`%2`G!1`')28GQ2,'F'DG!Z0))"?%(B<Y!@^'_
M2,'N&TR)R$PQP$P#A"28````2#'02(V\!Z'KV6Y(B<A(P>`%2`G&`?Y(B==(
MP>(>2,'O`D@)UTB)\H/G_TB)^$PQR$C!ZAM,`XPDH````$@QR$V-A`"AZ]EN
M2(GP2,'@!4@)PD0!PDF)R$C!X1Y)P>@"28G220G(2(G12<'J`D&#X/](P>D;
M3(G`2#'X2`.\)*@```!(,?!-C8P!H>O9;DB)T$C!X`5("<%$`<E)B?%(P>8>
M2<'I`DF)S$D)\4B)SD&#X?](P>X;3(G(3#'`3`.$)+````!(,=!(P>(>2(V\
M!Z'KV6Y)"=)(B<A!@^+_2,'@!4@)QDR)T`'^3#'(2<'L`D@QR$C!X1Y(B?)-
MC80`H>O9;DD)S$B)\$&#Y/],`XPDN````$C!X`5(P>H;2(GS2(N,),@```!(
M"<),B>!(P>L"3#'01`'"3`.4),````!(,?!(P>8>2(G738V,`:'KV6Y("?-(
MB="#X_](P>`%2,'O&T@)QTB)V$F)TTPQX$0!STG!ZP)(,=!(P>(>28GX38V4
M`J'KV6Y)"=-(B?A!@^/_2,'@!4G!Z!M)"<!,`>E,B=A%`=!,B=I,`>%("=A(
M(=I,B<9((?A)B?E(P>X;2`G02,'G'DG!Z0)(`<%,B<!)"?E(P>`%08/A_TV)
MPD@)QDR)R$R)R@'.2(N,)-````!,"=A,(=I,(<!(B?=("=!(P>\;2<'@'DP!
MZ4G!Z@)!O-;!8LI(`=E-"<)(`<%(B?!!@^+_2,'@!4R)TD@)QTR)T`'/2(N,
M)-@```!,"<A((?!)B?A,`>E,`=E,(<I)B?-("=!(P>8>2<'H&T@!P4B)^$G!
MZP)(P>`%20GS20G`08/C_T$!R$B+C"3@````3(G83`G03(G:3(G&3"'22"'X
M2,'N&TP!Z4@)T$P!R4F)^4C!YQY(`<%,B<!)P>D"2,'@!4D)^4@)QD&#X?\!
MSDB+C"3H````3(G(3`G83(G*2(GW3"':3"'`3`'I2`G03`'138G"2`'!2(GP
M2,'O&TC!X`5)P>`>2<'J`D@)QTT)P@'/08/B_TB+C"3P````3(G03(G228GX
M3`G(3"'*2<'H&TP!Z4@A\$@)T$P!V4F)\T@!P4B)^$C!YAY(P>`%2<'K`DD)
MP$D)\T$!R$&#X_](BXPD^````$R)V$R)VDR)QDP)T$PATDC![AM,`>E((?A(
M"=!,`<E)B?E(`<%,B<!(P>`%2`G&`<Y(P><>2<'I`DD)^4B+C"0``0``2(GW
M08/A_TC![QM,B<A,B<I,"=A,(=I,`>E,(<!,`=%-B<)("=!)P>`>2<'J`D@!
MP4B)\$T)PDC!X`5!@^+_2`G'3(G03(G2`<](BXPD"`$``$P)R$PARD@A\$F)
M^$@)T$G!Z!M,`>E,`=E)B?-(P>8>2`'!2(GX2<'K`DC!X`5)"<!!`<A)"?-(
MBXPD$`$``$&#X_],B<9,B=A,B=I(P>X;3`G03"'23`'I2"'X3`')28GY2`G0
M2,'G'DG!Z0)(`<%,B<!)"?E(P>`%08/A_T@)QDR)R$R)R@'.2(N,)!@!``!,
M"=A,(=I,(<!(B?=("=!(P>\;3`'I3`'138G"2<'@'D@!P4B)\$G!Z@)(P>`%
M30G"2`G'08/B_P'/2(N,)"`!``!,B=!,B=))B?A,`>E,`=E,"<A,(<I((?!)
MB?-)P>@;2`G02,'F'DG!ZP)(`<%(B?A)"?-(P>`%08/C_TD)P$R)V$R)VD$!
MR$B+C"0H`0``3`G03"'22"'X3(G&2`G02,'N&TP!Z4P!R4F)^4C!YQY(`<%,
MB<!)P>D"2,'@!4D)^4@)QD&#X?\!SDB+C"0P`0``3(G(3`G83(G*2(GW3"'`
M3`'I3`'13"':38G"2`G02<'@'DC![QM(`<%(B?!)P>H"2,'@!4T)PD@)QT&#
MXO\!STB+C"0X`0``3(G03`G(3(G228GX3"'*2"'P2<'H&TP!Z4@)T$P!V4F)
M\TC!YAY(`<%(B?A)P>L"2,'@!4D)\TD)P$&#X_]!`<A(BXPD0`$``$R)V$P)
MT$R)VDR)QDPATD@A^$P!Z4@)T$P!R4F)^4@!P4R)P$C![AM(P>`%2,'G'DG!
MZ0)("<9)"?D!SD&#X?](BXPD2`$``$R)R$R)RDB)]TP)V$PAVDC![QM,`>E,
M(<!("=!,`=%-B<)(`<%(B?!)P>`>2,'@!4G!Z@)("<=-"<(!ST&#XO](BXPD
M4`$``$R)T$R)TDF)^$P)R$PARDG!Z!M,`>E((?!("=!,`=E)B?-(`<%(B?A(
MP>`%20G`00'(2,'F'DG!ZP))"?-(BXPD6`$``$R)QD&#X_](P>X;3(G83(G:
M3`'I3`G03"'23`')2"'X28GY2`G02,'G'DG!Z0)(`<%)"?E,B<!!@^'_3`.L
M)&`!``!(P>`%2`G&3(G(3(G*3`G83"':`<Y,(<!(B?=("=!-`=5(P>\;20'%
M2(GP38G"2,'@!4G!X!Y)P>H"2`G'2(N4)&@!``!$`>]-"<))B?!!@^+_2(GY
M2<'H`DR)T$P!XDC!Z1M,,<A,`=I(,?!(P>8>2`'"2(GX20GP2,'@!4&#X/](
M"<%,B<`!T4B+E"1P`0``3#'02#'X2(G.2,'N&TP!XDP!RDF)^4C!YQY(`<)(
MB<A)P>D"2,'@!4D)^4@)QD&#X?\!UDB+E"1X`0``3(G(3#'`2(GW2#'(3`'B
M3`'228G*2`'"2(GP2,'O&TC!X`5(P>$>2<'J`D@)QTD)R@'72(N4)(`!``!!
M@^+_3(G02(GY3#'(2,'I&TP!XD@Q\$P!PDF)\$C!YAY(`<)(B?A)P>@"2,'@
M!4D)\$@)P4&#X/\!T4B+E"2(`0``3(G`3#'02(G.2#'X2,'N&TP!XDP!RDF)
M^4C!YQY(`<)(B<A)P>D"2,'@!4D)^4@)Q@'62(N4))`!``!!@^'_3(G(2(GW
M3#'`2,'O&TP!XD@QR$P!TDF)RDC!X1Y(`<)(B?!)P>H"2,'@!4D)RD@)QT&#
MXO\!UTB+E"28`0``3(G03#'(2(GY2#'P2,'I&TP!XDP!PDF)\$C!YAY(`<)(
MB?A)P>@"2,'@!4D)\$@)P4&#X/\!T4B+E"2@`0``3(G`3#'02(G.2#'X2,'N
M&TP!XDP!RDF)^4@!PDB)R$C!X`5(P><>2<'I`D@)QDD)^0'62(N4)*@!``!!
M@^'_3(G(2(GW3#'`2,'O&TP!XD@QR$P!TDF)RDC!X1Y(`<)(B?!)P>H"2,'@
M!4D)RD@)QT&#XO\!UTB+E"2P`0``3(G03#'(2(GY2#'P2,'I&TP!XDP!PDF)
M\$C!YAY(`<)(B?A)P>@"2,'@!4D)\$@)P4&#X/\!T4B+E"2X`0``3(G`2(G.
M3`'B3#'02,'N&T@Q^$P!RDF)^4@!PDB)R$C!YQY(P>`%2<'I`D@)QDD)^0'6
M2(N4),`!``!!@^'_3(G(2(GW3#'`2,'O&TP!XD@QR$P!TDF)RDC!X1Y(`<)(
MB?!)P>H"2,'@!4D)RD@)QT&#XO\!UTB+E"3(`0``3(G03#'(2(GY2#'P2,'I
M&TP!XDP!PDF)\$@!PDB)^$C!X`5("<%(P>8>2<'H`@'120GP2(N4)-`!``!!
M@^#_2(G.3(G`2,'N&TP!XDPQT$@Q^$P!RDF)^4@!PDB)R$C!YQY(P>`%2<'I
M`D@)QDD)^0'62(N4)-@!``!!@^'_3(G(2(GW28GS3#'`2,'O&TP!XD@QR$P!
MTDF)RDC!X1Y(`<)(B?!)P>H"2,'@!4D)RD@)QT&#XO\!UTB+E"3@`0``3(G0
M2(GY2(G[3`'B3`'"3#'(2,'I&T@Q\$G!ZP)(P>8>2`'"2(GX20GS2,'@!4&#
MX_](P>L"2`G!3(G8`=%(BY0DZ`$``$PQT$@Q^$F)R$C!YQY)P>@;2`G[3`'B
M@^/_3`'*28G)2`'"2(G(2,'@!4D)P$B)V$$!T$B+E"3P`0``3#'82#'(3(G'
M3(G&2,'O&TP!XDP!TD@!PDR)P$C!X`5("<<!UTC!X1Y)P>D"20G)2(N4)/@!
M``!(P>X"08/A_TB)^4R)R$C!Z1M,`>)(,=A,`Z0D``(``$PQP$P!VDG!X!Y(
M`<),"<9(B?A(P>`%@^;_2`G!2(GP20'<3#'(`=%(,?A(B<I)`<1(B<A(P>(%
M2,'H&T@)T$0!X$0!\$B)10!(B?A(P><>2,'H`@--"$@)^`-%$`-U&$0#32!(
MB4T(2(E%$$B)=1A,B4T@2('$"`(``%M=05Q!74%>PTR)9"3@3(E\)/A)B?Q(
MB5PDT$B);"3828GW3(EL).A,B70D\$B#[#A(A?]U)3'`2(M<)`A(BVPD$$R+
M9"083(ML)"!,BW0D*$R+?"0P2(/$.,-,BS6WDB``387V=,\/M@>$P'4$,<#K
M%SP]2(GZ=/5(@\(!#[8"A,!U18G01"G@28LN2(7M=*5,8^A,B?-FD$R)ZDR)
MYDB)[^AVYO__A<!U"DF-1"T`@#@]=!I(BVL(2(/#"$B%[777Z6____]FD#P]
M=:SKM4PI\TB#P`%(P?L#08D?Z5;___\/'X``````55-(B?M(@^P82(UL)!1F
MD#'`2(GN2(G?Z`/___](A<!T)DAC1"042(T4Q0````!(`Q7ZD2``2(/""$B+
M`DB%P$B)0OAU\.O(2(/$&%M=PY!(@^P8,<!(C70D%.C`_O__2(/$&,,/'T0`
M`&8/'T0``$B#[`B#/66,(`#_=`N+!5V,(`!(@\0(PS'`OTA30`#HO/___TB%
MP'0'#[8`A,!U$S'`B04XC"``BP4RC"``2(/$",,\,`^5P`^VP.OE#Q\`2(/L
M"+______Z&;D__\Q]K\P.$``2(/$".G6YO__9I!(BP59C"``4S'VO^940`!(
MBT@(2(L%+HP@``^W4"`/M@7[BR``9H'B_P&#X'_!X@<)PF:)40)(BP4CC"``
M2(M8".C^Y?__2(E#*$B+!0^,(`!(BU`(2(L%](L@`$B)0C!(BP7YBR``,=)(
MBT@(2(L%A(P@`$B%P'0'2(N0J````$B)43A(BP75BR``2(M`"$C'0$``````
M2(L%PHL@`$B+0`A(QT`@`````$B+!:^+(`!(BU`(2(L%K(L@`$B)0DA;PP\?
M@``````/'X``````3(ED).A(B5PDV$F)_$B);"3@3(EL)/!,B70D^$B![*@`
M``!(A?]T!8`_`'4S2(N<)(````!(BZPDB````$R+I"20````3(NL))@```!,
MB[0DH````$B!Q*@```###Q\`Z*_D__](A<!(B<5TP`\?`$B)[^C,XO__2(7`
M#X2A````2(U8"+]34T``N0(```#\2(G>\Z9TV;]24T``N0,```!(B=[SIG3(
M3(GGZ$3C__](B=])B<7H.>/__T&-1`4"2&/XZ)SA__](B=E(B<=)B<5,B>*^
M55-``#'`Z-3B__](B>9,B>_H:>+__X/``701#[=$)`@E`/```#T`0```=#9,
MB>_H*^+__TR)[^B3Y/__2(GOZ"OB__](A<`/A5____](B>_HNN3__TR)Y^A"
MX___Z?;^__],B>_HP?[__Y#KQP\?@``````/'X``````4TB)^TB#Q(!(B>;H
MY.+__X7`=1@/MT0D""4`\```/0!```!T#ST`H```=`A(@^R`,<!;PTB)W[X"
M````Z"/C__^%P`^4P$B#[(!;#[;`PY!!5S'`059)B?Y!54%454B)]5-(@^P8
M@#X]#Y3`2`'%2(GOZ"WB__](C70D%$&)QTR)]S'`Z)?[__](A<!(B<-T-TB)
MQ^@+XO__1(GZ2#G0#X*\````#[9%`$B#Q0&(`TB#PP&$P'7N2(/$&#'`6UU!
M7$%=05Y!7\-(BSUACB``13'DN!````!(@S\`=!](B?I(BT((08/$`4B#P@A(
MA<!U[T&-1"0"2)A(P>`#BQ7NB2``A=(/A1`!``!(B<?'!=F)(``!````Z/C?
M__](A<!)B<4/A!D!``!)8\1(BS7^C2``3(GO2(T<Q0````!(B=KH/^/__TR)
M+>2-(`!(BP7=C2``2,=$`P@`````1(ED)!1!#[863(GPA-(/A8@```"+7"04
M12GW08U\!P)(P>,#2`,=J8T@`.B(W___2(7`2(D##X2I````BU0D%$B+!8V-
M(`!(BQ3000^V!H3`B`)T)3P]="%,B??K#F8/'T0``$B#QP$\/70.#[9'`4B#
MP@&$P(@"=>K&`CT/'X``````#[9%`$B#Q0&(0@%(@\(!A,!U[>F__O__@/H]
M#X1O____2(/``0^V"(3)#X1@____@/D]=>SI5O___TB)Q@\?`.A_X?__2(7`
M2(D%`8T@`'0026/$2(T<Q0````#I"____TB#Q!BX_____UM=05Q!74%>05_#
M#Q]$``!F#Q]$``!!5T%628G^055!5$&\95-``%532(/L2$R+/9(8``!)B>5(
MQP0D95-``$C'1"0(6U-``$C'1"00:%-``$C'1"087E-``$C'1"0@8U-``$C'
M1"0H=5-``$C'1"0P`````.L>3(GV3(GG,<#H@OW__TV+90A)@\4(387D#X2)
M````,<!,B>?H9_K__TB%P$B)Q730@#@`=,M,B?9(B<?HX^#__TB%P'7(3(GW
MZ);?__],B?](B</HB]___TB-7`,!2(GOZ'[?__](C3P#Z.7=__])B>A(B<=(
MB<-,B?E,B?*^D%1``#'`Z!K?__],B><QP$B)WNCY_/__38ME"$F#Q0A-A>0/
MA7?___](@\1(6UU!7$%=05Y!7\-F#Q^$``````!(@^PXOX!30`!(BP7`AB``
M2(E$)"@QP$B+!4(7``!(B00D2(L%/Q<``$B)1"0(2(L%.Q<``$B)1"002(L%
M-Q<``$B)1"08#[<%,Q<``&:)1"0@,<#H)_G__S'`OXE30`#H&_G__S'`OY%3
M0`#H#_G__S'`OYI30`#H`_G__S'`OZ%30`#H]_C__S'`O[%30`#HZ_C__S'`
MO[U30`#HW_C__S'`OTA30`#HT_C__S'`O\930`#HQ_C__S'`O]!30`#HN_C_
M_S'`O]I30`#HK_C__S'`O^=30`#HH_C__S'`O_!30`#HE_C__S'`O_M30`#H
MV_C__TB%P'0/2(G&O\930``QP.C'^___,<"_#%1``.B[^/__2(7`=`](B<:_
M'E1``#'`Z*?[__\QP+\I5$``Z)OX__](A<!T-DB)QK^]4T``,<#HA_O__S'`
MOE540`"_H5-``.AV^___2(M$)"A(,P5JA2``=5%(@\0XPP\?`#'`OSE40`#H
M5/C__TB%P'012(G&OTA30``QP.A`^___Z[=(C70D$;]*5$``N0H```#\\Z9U
MHTB-="0;OTA30``QP.@9^___ZY#H1M[__V:02(/L".B[W?__B<?HY-O__S'2
M2(7`=`-(BQ!(B=!(@\0(PP\?@``````/'X``````55-(B?M(@^P(2(7_=`@/
MMB]`A.UU$$B#Q`B_4U-``%M=Z:[<___H"=W__T@!V$B-4/](.=,/@YX```!(
MBSU6%0``#[9`_P^V-T`X\'0)ZRH/M@HXP75F2(/J`4@YTV:0<NY(.=IU*4`Z
M+W2J2(/$"%M=Z5W<__\/M@)`.,9TXTB#Z@%(.=-R[^O89@\?1```2(/J`4@Y
MTW,)#[8".@=FD'3N2"G:,<E(C4("2#T`!```=@Y(@\0(2(G(6UW#B<CKN4B#
MP@%(B=Z_8,5@`.@RW?__N6#%8`#KVDB+/;@4``#K@`\?@``````/'X``````
M2(E<)/!(B6PD^$B#[!A(B?OH^O[__TB)Q^ARW___2(G%,<#HZ/;__X7`=`I(
MA=MT!8`[`'4/2(M<)`A(BVPD$$B#Q!C#OE=40`!(B>_H,MW__T@YQ77?2(G?
M2(ML)!!(BUPD"$B#Q!CIX_?__P\?`%-(@^P@B7PD'$B)="002(U\)!Q(B50D
M"$B-="002(U4)`CH?=W__X`]DH,@```/A"D!``"+1"0<@`T!@R```X/`!4AC
MR$B%R0^(2@$``/)(#RK!\@]8!<UP``!F#RX%S7````^'3`$``$B-/,T`````
MZ,[<__](BW0D$$B)P4B)!=.'(`!,C4GX2(L&2,=!"%Q40`!(B0%(BP5J@B``
M2,=!&%]40`!(B4$01(M$)!S'!9>'(``$````08/X`7XF3(U)^+\!````N@@`
M```/'P!(BP06@\<!2(E$"AA(@\((03GX?^M!C4`$OM!20`!%,<!(F$G'!,$`
M````BU0D'$B+/3J'(`"#P@/H9MG__X7`B<-T<4B+/26'(`#H9-O__S'`O[%3
M0`#H5/7__TB%P'092(L]"(<@`.@7V?__Z'+:__^)V$B#Q"!;PTB+/?>&(`!(
MA?]T<.@U_O__Z]0/'P#HW]G__TB%P$B)QTB)!<Z&(`!T=.B;VO__Q@6@@2``
M`.FO_O__2(L]M(8@`.@3V?__B</I?/___TB)R$B)RDC1Z(/B`4@)T/)(#RK`
M\@]8P.F>_O__OO#$8`"_W51``#'`Z*[;__^_O5-``.BP]/__2(7`2(G'2(D%
M:X8@``^%<____^E)____0+<!Z'3;__]!5T%6055!5$F)_+^]4T``55-(B?-(
M@>RH!```2(L%;8$@`$B)A"28!```,<#H7O3__TB++0\2``!,B>=)B<5(B>[H
MW=K__TB%P'0Y3(GFO]I30``QP.@U]___2(N4))@$``!(,Q4F@2``3(G@#X4T
M`0``2('$J`0``%M=05Q!74%>05_#3(GGZ%?9__],BSV\$0``2(G?08G&3(G^
MZ&+8__](A<!(B<-THD&#Q@%$B70D#$R-M"20````#Q]$``"`.P"X4U-``$@/
M1-A-A>UT#TB)WDR)[^@(V___A<!T?DB)W^C\V/__B<%(F`^V1`/_.D4`=1V-
M0?](F$B-%!B0#[9"_\8"`(/I`4B#Z@$Z10!T[8M$)`P!R#W_`P``#X\H____
M38G@2(GI2(G:OI!40`!,B?<QP.AHV/__2(UT)!!,B??H^]?__X7`=1$/MT0D
M&"4`\```/0"```!T&S'_3(G^Z)S7__](A<!(B<,/A4S____IT_[__[X!````
M3(GWZ![9__^%P'743(GVO]I30`#H^?7__TR)]^CEU___28G$Z;3^___H&-G_
M_P\?0`!!5TF)_[^]4T``059!54%455-(@>SH@0``2(L%P'\@`$B)A"38@0``
M,<!(QX0DT````&)40`!(QX0DV````&=40`!(QX0DX`````````#HC?+__TB%
MP$B)PW0)@#@`#X6/`@``,<!(C:PDT````.A=^O__2(7`2(G##X3'`0``2(G?
MZ*W7__](C7P``>@3UO__@#L`28G%="9(B<4/'T``#[832(GO,<"^=U1``$B#
MPP%(@\4"Z#K7__^`.P!UX4B-K"2@````OQY40`!(QX0DH````!Y40`!(QX0D
MJ````!=40`!(QX0DL````'Q40`!(QX0DN````#140`!(QX0DP````(140`!(
MQX0DR`````````#K$4B+?0A(@\4(2(7_#X1.`0``,<#HLO'__TB%P$B)PW3@
M@#@`=-M(B<?H3?3__X7`=,](B=_HA=;__TB%P$F)Q`^$'0$``$R)Y^C1UO__
M3(GO2(G#Z,;6__^-A`,$!```2&/H2(GOZ"35__](BQ41#P``2(G'28G&38GI
M0;A75$``OHY40``QP$B)T4B)5"003(GBZ$?6__^^P`$``$R)]^CJUO__@\`!
M#X1(`0``2(UT)"!,B??HM-;__X7`=14/MT0D*"4`\```/0!````/A%@!``!)
MBQ=(BSUM?B``3(GQOJA50``QP#'MZ.#5__](BY0DV($``$@S%<U](`!(B>@/
MA7,"``!(@<3H@0``6UU!7$%=05Y!7\-(B<?HGM7__TB)PTB#Q0A(A=L/A3G^
M__](BWT`2(7_#X0R`@``,<#HAO#__TB%P'3:@#@`=<I(@\4(2(7;=-D/'P#I
M"O[__T4QY(`]20T```!(QX0D\````(A40`"[B%1``$C'A"3X````4U-``$C'
MA"0``0```````$B-K"3P````=2CII/[__TV%Y`^%F_[__TB+70A(A=L/A([^
M__](@\4(@#L`#X2!_O__2(G?Z*[R__^%P'312(G?Z.;4__])B<3KQ$B)Q^CU
M]/__2(G?Z-'4__](B<7I^?[__^@TUO__@S@1#X2J_O__Z";6__])BQ=$BP!,
MB?%(BSTR?2``OFA50``QP#'MZ*C4___IP_[__XM<)"SH2M7__SG##X67_O__
M#[=$)"@E_P$``#W``0``#X6"_O__2(GOZ#73__^_7E-``$B)Q3'`Z&+O__](
MA<!(B<</A`L!``#H1=3__TF+/TB)QNBV^O__2(7`28G$#X3O````3(GGZ(;4
M__^#^`-!B<`/CV4%```QP.@_[___A<!U%C'V3(GGZ"73__^%P(E$)!P/A<(`
M``"^551``+](4T``,<#H]/'__^B3U?__2(M,)!!!B<!!N>940`!,B?*^L%1`
M`$B)[S'`,=OHX=/__^LZZ"K5__^#.!$/'P!U/^A=U?__2(M,)!"#PP%!B<!!
MB=E,B?*^OE1``$B)[S'`2,<$).940`#HI=/__[[``0``2(GOZ$C4__^#P`%T
MM$R)]^A[U?__2(GNO[U30``QP.AH\?__2(GOZ'#S___I?_W__[MP5$``Z?#[
M__^0Z'_4__]-BR?I"?___[H"````2,?&[O___XG'Z'33__^+?"0<2(VT)!`!
M``"Z!@```.B.T___@+PD$`$```!U#H"\)!$!``!##X38!```BWPD'#'V,=),
MC:0D$($``.@QT___OXFKS>^^_MRZF+GPX=+#2,>$)!"!```!(T5G2(F\)!B!
M``!)@\0X2(FT)""!``!(QX0D*($``'94,A!(B8PD,($``$C'A"0X@0``````
M`$C'A"1`@0```````,>$)(B!````````BWPD'$B-M"00`0``N@"```#HY=+_
M_X7`08G%#XXZ`0``2(N,)#B!``!)8]5(BX0D0($``$B-G"00`0``C3312#G.
M2(FT)#B!``!(@]``2,'J'4B)A"1`@0``2`&4)$"!``"+E"2(@0``A=)T:>F%
M````#Q]$``!(BP-(C;PD$($``$&#[4!(B80D2($``$B+0PA)B40D"$B+0Q!)
MB40D$$B+0QA)B40D&$B+0R!)B40D($B+0RA)B40D*$B+0S!)B40D,$B+0SA(
M@\-`28E$)#CHD=7__T&#_3]_FTECU4B)WDR)Y^@AT___1(FL)(B!``#I"?__
M_[A`````2&/Z2(VT)!`!```IT$F-/#Q!.<6)PT$/3MU,8_M,B?KHZM+__XG8
M`X0DB($``(/X0(F$)(B!```/A<;^__](C8PD$`$``$$IW4B-O"00@0``28T<
M#^@1U?__Z7O___^+?"0<Z$?1__](BYPD.($``$R+I"1`@0``2(G82,'H`X/@
M/TACT(/``8/X.,:$%$B!``"`#XZG`@``2&/XND`````Q]BG"2(V\/$B!``!(
M8]+HBM+__TB-O"00@0``Z*G4__](C;PD$($``+D'````,<#\2(/'./-(JTR)
MX$B-O"00@0``1(BD)(.!``!(P>@8B)PDAX$``$R-O"20@0``B(0D@($``$R)
MX$R-K"3`@0``2,'H$(B$)(&!``!,B>!-B?Q(P>@(B(0D@H$``$B)V$C!Z!B(
MA"2$@0``2(G82,'H$(B$)(6!``!(B=@QVTC!Z`B(A"2&@0``Z`W4__](BY0D
M$($``$B)T(B4),.!``!(P>@8B(0DP($``$B)T$C!Z!"(A"3!@0``2(G02(N4
M)!B!``!(P>@(B(0DPH$``$B)T(B4),>!``!(P>@8B(0DQ($``$B)T$C!Z!"(
MA"3%@0``2(G02(N4)""!``!(P>@(B(0DQH$``$B)T(B4),N!``!(P>@8B(0D
MR($``$B)T$C!Z!"(A"3)@0``2(G02(N4)"B!``!(P>@(B(0DRH$``$B)T(B4
M),^!``!(P>@8B(0DS($``$B)T$C!Z!"(A"3-@0``2(G02(N4)#"!``!(P>@(
MB(0DSH$``$B)T(B4)-.!``!(P>@8B(0DT($``$B)T$C!Z!"(A"31@0``2(G0
M2,'H"(B$)-*!``!"#[84*TR)YS'`OG=40`!(@\,!28/$`N@(S___2(/[%'7>
MQH0DN($```!!N>940`!-B?A(BTPD$$R)\KZA5$``2(GO,<#HVL[__^E"^___
M2)B_EU1``$F-=`3\N`4```#\2(G!\Z8/A7[Z__]!@_@$=!E!C4#\2(M4)!!(
MF$$/MD0$_SH"#X5?^O__28M?"$B%VP^$4OK__TB)W^C$SO__2(/X`P^&0/K_
M_TB-=`/\OYQ40`"Y!0```/SSIDP/1./I)?K__[HX````2&/X,?8IPDB-O#Q(
M@0``2&/2Z.//___I>/W__X"\)!(!``!!#X4:^___@+PD$P$``$,/A0S[__^`
MO"04`0``2`^%_OK__X"\)!4!``!%#X7P^O__BWPD'+H"````2,?&QO___^@A
MSO__BWPD'$B-M"00`0``NBD```#H.\[__TR-A"00`0``0;GF5$``Z=?^__\/
M'T``2(E<).A(B6PD\$R)9"3X2('L.`@``$B-G"00!```2(L%BW4@`$B)A"08
M"```,<#H(,___[G/5$``B<*^U%1``#'`2(G?Z'K-__^%P'DV,>U(BY0D&`@`
M`$@S%5%U(`!(B>AU8$B+G"0@"```2(NL)"@(``!,BZ0D,`@``$B!Q#@(``##
M2(G?N@`$``!(B>;H(,S__X7`B<-XM(UX`4AC_^C/R___2(7`=*1(8]M(B<5(
MB>9(B=I(B<?H=L[__\8$*P#KC.@;SO__#Q^``````.DK____#Q]$``!F#Q]$
M``!!5#'`OZ%30`#&!:AT(``!55/HN>?__TB%P'0)@#@Q#X2C`0``,<#HU.W_
M_[H+````O@$```"_X%1``.C4R___2(7`#X2`````,>V#/4YY(``!2(M`$$R+
M8"A^7+L(````ZRI(BW<02(L%.GD@`$B+/!CHK<[__X7`=3V#Q0%(@\,(C44!
M.045>2``?BLQTHGN3(GGZ"O-__](A<!T&DB+./9'#01UO#'VN@(```#HD<[_
M_TB)QNNOBQ7B>"``C4+_.>@/A-(```"Z!````+X!````O^540`#H-\O__TB%
MP$B)PW0B2(M`$+[G5$``2(LXZ"[+__](BT,02(LX]D<.0`^%U````+H$````
MO@$```"_^5-``.CYRO__2(7`2(G%="<QP+_:4T``Z*'F__](A<!(B<(/A-$`
M``!(BT402(G62(LXZ-K*__\QP+^]4T``Q@5@<R```$C'!3US(```````Z&CF
M__](A<!(B04F>"``=':^P`$``$B)Q^@3S/__A<!T$8/X$70,@_C_#Q\`#X6?
M````6UU!7,.#Z@%FD`^.(____[L!````#Q]$``!,B>>#PP'H2<K__SD=WW<@
M`'_MZ0'___^`>`$`#Q]```^$5O[__^E*_O__#Q]$``#H+\S__^D=____2(L]
MMW<@`.CZ\O__2(7`2(D%F'<@`'5MOP!60`#HN,S__^C?_?__2(7`2(G#=#M(
MBT402(G>2(LXZ/S)__](B=_HI,S__^D5____B<%(BP5J=R``2(L54W<@`+]0
M5D``2(LP,<#H<,S__TB+51!(BP5)=R``2(LZ2(LPZ+K)___IV_[__TB+11!(
MBQTN=R``2(LX]D<-!'0Z2(M_$$B)WNC%R?__B<-(BT402(LX]D<-!'0P2(M'
M$$B)PDB+!?QV(`")V;\H5D``2(LP,<#H!\S__[H"````,?;H>\S__TB)Q^NY
MN@(````Q]NAJS/__Z\8/'T``NNQ40`"^!!U``+_V5$``Z?#+__]F#Q]$``!F
M#Q]$``!(@^P(Z-?___^YYE1``$4QP+[03T``2(G*OQ)50`!(@\0(Z2W*__^0
MD)"0D)"0D)!52(GE4TB#[`A(BP7P;"``2(/X_W05,=O_T$B+@_B_8`!(@^L(
M2(/X_W7M2(/$"%O)PY"02(/L".B3S/__2(/$",,```````!005)?0TQ%04X`
M+BX`)7,O)7,`3$E"4$%42`!$64Q$7TQ)0E)!4EE?4$%42`!32$Q)0E]0051(
M`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,
M25I%1`!005)?4U!!5TY%1`!005)?5$5-4`!005)?1$5"54<`4$%27T-!0TA%
M`%!!4E]04D]'3D%-10!005)?05)'0P!005)?05)'5E\P`%!!4E]'3$]"04Q?
M1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,
M7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`<&%R+0`M90`M
M+0!54T52`%5315).04U%`%-94U1%30`E,#)X`%1%35!$25(`5$U0`"]T;7`O
M`"5S)7,E<R5S`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE
M=25S`"5S)7-T96UP+25U+25U)7,`9FEL90`O<')O8R\E:2\E<P!!4D=6`!@`
M<&5R;`!P97)L>'-I+F,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN
M=&5R;F%L<SHZ4$%2.CI"3T]4`#H``````````%]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@``````````",5$```````"=50```````)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U
M;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T
M:6]N*0H```````!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``
M````````)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL960@*&5R<FYO/25I*0H`
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H``````````",A+W5S<B]B:6XO<&5R;`IE
M=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*("`@
M(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G
M92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A
M;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T<FEC=#L*
M"B-L:6YE(#$U.`H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL
M92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@(')E<75I<F4@
M1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!R
M97%U:7)E($9I;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H<7%[4F5M;W9I
M;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I
M;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R
M7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$;VXG="!R96UO
M=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E('=I=&@@;W1H
M97(@87!P<PH@("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@
M:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["B`@("`@
M("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O
M<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P
M<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA
M<F5D"B`@("`@("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H870@
M87)E(&EN('5S92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD"B`@("`@("`@
M(R!S:&5L;"!C;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN
M('5S92!B>2!T:&ES('!R;V-E<W,N"B`@("`@("`@(R!$;VXG="!D;R!A;GET
M:&EN9R!O;B!7:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P<F]C97-S('=I
M;&P*("`@("`@("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N
M"@H@("`@("`@(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@("`@("`@
M("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@("`@1$E2(#T^
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@("`@("`@("`@
M("!3549&25@@/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)3DL@/3X@,"P*
M("`@("`@("`I.PH*("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ
M.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F("<D<&%R7W1E
M;7`G"B`@(&EF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@H@("`@("`@
M8G)E86L*("`@9FD*("`@<VQE97`@,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O
M;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@("`@("`@("`@
M(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@;7D@)&-M9"`]
M("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@
M("`@8VQO<V4@)'1M<#L*("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@("`@
M;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M
M(&-L96%N=7`Z("D*("`@("`@("`@("`@("X@)'1M<"T^9FEL96YA;64I.PH@
M("`@?0I]('T*"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@
M:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@("`@979A;"![
M"@I?<&%R7VEN:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%21U9?
M,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA<"`D
M14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I
M.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@9F]R
M("AK97ES("5%3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY0
M05)?05)'5E\O.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PH*(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051("FUY
M("5#;VYF:6<@/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7
M:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@
M+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?
M9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G
M+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC
M($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D
M(&UO9'5L97,@>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@
M("!L;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H96-K
M(&9I;&4@='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@
M(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN;6]D
M92A?1D@I.PH*("`@(&UY("1B=68["B`@("!S965K(%]&2"P@+3@L(#(["B`@
M("!R96%D(%]&2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@97$@
M(EQN4$%2+G!M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R96%D
M(%]&2"P@)&)U9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB
M+"`D8G5F*2P@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D871A
M7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X=')A
M8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E<75I
M<F5?;&ES=#L*("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@
M(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@)&)U
M9CL*("`@("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B
M+BXN*2D["B`@("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;
M82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H)&)A
M<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI
M?"D["@H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@*&1E
M9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I
M*2!["B`@("`@("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F
M:6QE*"1E>'0L("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@
M("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R
M:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@
M("`@("`@("`@("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L
M;&YA;65](#T@)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@
M("`@("`@(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@("`@(R!S:&]U
M;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@)&9I
M;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@("`@
M("`@("`@("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@("`@
M("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@
M("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT("1O
M=70@)&)U9CL*("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]"B`@
M("`@("`@96QS92!["B`@("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2`]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD
M9G5L;&YA;65](#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^("1B=68L"B`@
M("`@("`@("`@("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@(&YA
M;64@/3X@)&9U;&QN86UE+`H@("`@("`@("`@("!].PH@("`@("`@('T*("`@
M("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@("`@
M;&]C86P@0$E.0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO9'5L
M92D@/2!`7SL*"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PH*("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I
M<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K97D[
M"B`@("`@("`@("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@
M("`@("`@("`@("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@
M("`@("`@("`@("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F
M:6YE9"@D:V5Y*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@("`@("`@)$E.
M0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@
M("`@("`@:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I
M;&4Z.FYE=RDI('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I
M.PH@("`@("`@("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@
M("`@("`@("`@<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U<FX@
M)&9H.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@;7D@
M*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[
M8W)C?2D["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@
M("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D
M9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D
M;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@
M("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB
M.PH@("`@?2P@0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F
M:6QE<R![>WL*"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C
M97-S:6YG"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!005(Z
M.DAE879Y.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PH*("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E<B!M
M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*("`@
M(",@;&]A9"!R97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F
M:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*("`@
M("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@
M;F4@)TU35VEN,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD9FEL96YA;65]
M(&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@("`@("`C(')E
M<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PH@("`@
M("`@("`@("!I9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*("`@("`@
M("`@("`@("`@(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3:VEP($%C=&EV
M95-T871E)W,@<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@("`@("`@
M("`@9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T
M;VUI>F5<+G!L)"\["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@('T*"B`@("`C
M('U]?0H*("`@(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PH@
M("`@)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R
M9W5M96YT('!R;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*;7D@*"1O=70L
M("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*9&5L971E("1%3E9[
M4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E
M8W5R:71Y('!R;V)L96TI"@HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$
M14)51WT["B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D
M(&5X96-U=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R
M=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF
M="DI('L*("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB
M7W1O7W!A<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U
M;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@
M('9E<FEF>5]P87(*("`@("D["@H@("`@(R!I9B!T:&4@87!P(&ES(&EN=F]K
M960@87,@(F%P<&YA;64@+2UP87(M;W!T:6]N<R`M+7)E=7-E(%!23T=204T@
M0%!23T=?05)'5B(L"B`@("`C('5S92!T:&4@87!P('1O(')U;B!T:&4@9VEV
M96X@<&5R;"!C;V1E(&EN<W1E860@;V8@86YY=&AI;F<@9G)O;2!T:&4*("`@
M(",@87!P(&ET<V5L9B`H8G5T('-T:6QL('-E="!U<"!T:&4@;F]R;6%L(&%P
M<"!E;G9I<F]N;65N="!A;F0@0$E.0RD*("`@(&EF("A`05)'5B!A;F0@)$%2
M1U9;,%T@97$@)RTM<F5U<V4G*2!["B`@("`@("`@<VAI9G0@0$%21U8["B`@
M("`@("`@)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PH@("`@
M?0H@("`@96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"@H@("`@("`@
M(&UY($!A9&1?=&]?:6YC.PH@("`@("`@('=H:6QE("A`05)'5BD@>PH@("`@
M("`@("`@("`D05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI
M+R!O<B!L87-T.PH*("`@("`@("`@("`@:68@*"0Q(&5Q("=))RD@>PH@("`@
M("`@("`@("`@("`@<'5S:"!`861D7W1O7VEN8RP@)#(["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@
M("`@("`@979A;"`B=7-E("0R(CL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-I9B`H)#$@97$@)T$G*2!["B`@("`@("`@("`@("`@("!U;G-H:69T
M($!P87)?87)G<RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS
M:68@*"0Q(&5Q("=/)RD@>PH@("`@("`@("`@("`@("`@)&]U="`]("0R.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G8B<I('L*
M("`@("`@("`@("`@("`@("1B=6YD;&4@/2`G<VET92<["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=")RD@>PH@("`@("`@("`@
M("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<VEF("@D,2!E<2`G<2<I('L*("`@("`@("`@("`@("`@("1Q=6EE
M="`](#$["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q
M("=,)RD@>PH@("`@("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R
M(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)U0G*2!["B`@("`@("`@
M("`@("`@("`D8V%C:&5?;F%M92`]("0R.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!S:&EF="A`05)'5BD["@H@("`@("`@("`@("!I9B`H;7D@)&-M
M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@("`@("`@(&1E;&5T92`D
M14Y6>R=005)?5$5-4"=].PH@("`@("`@("`@("`@("`@:6YI=%]I;F,H*3L*
M("`@("`@("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@
M("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@
M("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!
M4D=6.PH@("`@("`@("`@("`@("`@97AI=#L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*("`@
M('T*?0H*(R!86%@@+2T@861D("TM<&%R+61E8G5G('-U<'!O<G0A"@HC('U]
M?0H*(R!/=71P=70@;6]D92`H+4\I(&AA;F1L:6YG('M[>PII9B`H)&]U="D@
M>PH@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,
M15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ
M1FEL93L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*"B`@
M("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PH@("`@;7D@)'II<#L*"@H@("`@
M:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L
M("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@
M("!B:6YM;V1E*"1F:"D["B`@("`@("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G
M*3L*"B`@("`@("`@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@
M("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@("`@("`@("`@;W(@9&EE(")296%D
M("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@?0H*"B`@("!M>2`E96YV(#T@9&\@
M>PH@("`@("`@(&EF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E
M;G1S*"=-151!+GEM;"<I*2!["B`@("`@("`@("`@("1M971A(#U^(',O+BI>
M<&%R.B0O+VUS.PH@("`@("`@("`@("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*
M("`@("`@("`@("`@)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@
M("`@("`@('T*("`@('T["@H@("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@
M9FEL97,@>WM["B`@("!L;V-A;"`D+R`](%PT.PH*("`@(&EF("AD969I;F5D
M("1P87(I('L*("`@("`@("!O<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B
M)"$Z("1P87(B.PH@("`@("`@(&)I;FUO9&4H4$%2*3L*("`@("`@("!D:64@
M(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<
M,#`S7#`P-"(["B`@("!]"@H@("`@0W)E871E4&%T:"@D;W5T*2`["B`@("`*
M("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<H"B`@("`@("`@)&]U="P*("`@
M("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`H@("`@("`@(#`W-S<L"B`@("`I
M(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*"B`@("`D+R`]("AD969I
M;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["B`@("!S965K
M(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["B`@
M("!I9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_
M.B,A?%Q`<F5M*2\I('L*("`@("`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<#L*("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^
M87!P;'DH7"1L;V%D97(L("0P*0H@("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y
M("AS;W)T(&ME>7,@)65N=BD@>PH@("`@("`@(&UY("1V86P@/2`D96YV>R1K
M97E](&]R(&YE>'0["B`@("`@("`@)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L
M(#U^("]>6R<B72\["B`@("`@("`@;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B
M("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@("`@(&UY("1S970@/2`B4$%27R(@
M+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@("`@("`@)&QO861E<B`]?B!S>R1M
M86=I8R@@*RE]>PH@("`@("`@("`@("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X
M("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*("`@("`@("!]96<["B`@
M("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*
M("`@(",@?7U]"@H@("`@(R!7<FET92!B=6YD;&5D(&UO9'5L97,@>WM["B`@
M("!I9B`H)&)U;F1L92D@>PH@("`@("`@(')E<75I<F4@4$%2.CI(96%V>3L*
M("`@("`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@
M("`@:6YI=%]I;F,H*3L*"B`@("`@("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@
M("`@("`@(&UY($!I;F,@/2!S;W)T('L*("`@("`@("`@("`@;&5N9W1H*"1B
M*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@
M("$O0E-$4$%.+PH@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("@D8G5N
M9&QE(&YE("=S:71E)RD@;W(*("`@("`@("`@("`@*"1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@("`@("`@("`@("1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["B`@("`@("`@?2!`24Y#.PH*
M("`@("`@("`C($9I;&4@97AI<W1S('1E<W0@861D960@=&\@9FEX(%)4(",T
M,3<Y,#H*("`@("`@("`C($9U;FYY+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@
M7SPN+BXN875T;R]#;VUP<F5S<R]287<O6FQI8B]A=71O<W!L:70N:7@N"B`@
M("`@("`@(R!4:&ES(&ES(&$@8F%N9"UA:60@9FEX('=I=&@@;F\@9&5E<&5R
M(&=R87-P(&]F('1H92!I<W-U92X*("`@("`@("`C(%-O;65B;V1Y('!L96%S
M92!G;R!T:')O=6=H('1H92!P86EN(&]F('5N9&5R<W1A;F1I;F<@=VAA="=S
M(&AA<'!E;FEN9RP*("`@("`@("`C($D@9F%I;&5D+B`M+2!3=&5F9F5N"B`@
M("`@("`@;7D@)69I;&5S.PH@("`@("`@("]>7SPH+BLI)"\@86YD("UE("0Q
M(&%N9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE
M<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT
M(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET
M=&5N.PH*("`@("`@("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@
M("`@("`@("`@(&UY("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA
M;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@
M("`@("`@("`@("1F:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@("`@;&%S
M=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("@O
M7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@
M("`@("`H)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@
M("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!E;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@
M("`@("`@("`@("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD,7TI('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F
M:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!E;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET
M=&5N>R1N86UE?2LK.PH@("`@("`@("`@("!N97AT(&EF("%R968H)&9I;&4I
M(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@("`@("`@
M;W5T<R@@:F]I;B`B(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL
M(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@
M("`@("`@('%Q*"(N+BXI"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!M
M>2`D8V]N=&5N=#L*("`@("`@("`@("`@:68@*')E9B@D9FEL92DI('L*("`@
M("`@("`@("`@("`@("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E
M;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@
M)"$B.PH@("`@("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@
M("`@("`@("1C;VYT96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO
M<V4@1DE,13L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@
M("`@("`@("!I9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O
M7"XH/SIP;7QI>'QA;"DD+VD["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M+"`D;F%M92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H
M5W)I='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H
M(D9)3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N
M9W1H*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I
M;G1F*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI
M.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O
M;G1E;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@
M("`@("`@('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T
M('1H92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET
M951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@
M/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?
M;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@
M("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E
M<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@
M("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$
M-2T^;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I
M9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I
M;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@
M("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I
M;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U
M="P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I
M*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@
M("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S
M92@D9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C
M:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@
M("!]"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C
M86-H95]N86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12(["B`@("`D
M9F@M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G
M3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP
M<FEN="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D
M(#`W-34L("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@
M4')E<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@
M("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?
M<')O9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@
M<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2
M.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("![
M"B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@
M)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0[
M"B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@
M9&EE("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE
M("(D(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@
M("`D4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I
M970@/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?
M5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I
M;G0A"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R
M<R`I('L*("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R
M>3L*("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL
M94YA;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]
M?B!M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI
M8B\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N
M?2\I/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN
M86UE?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@
M("`@)`H@("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ
M4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D[
M"B`@("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE
M;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O
M=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A
M9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M
M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@
M)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@
M("`@("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q
M(")H<'5X(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@
M?7U]"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@
M<VAO=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65]*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P
M(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP
M87(@72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U
M=&9I;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A
M=&50871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D
M97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN
M*B<I*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&
M:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@
M;6MP871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S
M('L*("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>
M3R!N92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E
M($1Y;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E
M('-T<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A
M<G,["B`@("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y
M.PH@("`@<F5Q=6ER92!%<G)N;SL*("`@(')E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P[
M"B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P
M96,["B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<[
M"B`@("!R97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE
M.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C
M:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ
M2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT.PH@("`@<F5Q=6ER92!A='1R:6)U=&5S.PH@("`@979A
M;"![(')E<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q=6ER92!7:6XS,B!]
M.PH@("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["B`@("!E=F%L
M('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*("`@(&5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["B`@("!E=F%L
M('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*
M?0H*(R!4:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D92!A<'!E87)S(&EN(&UY
M;&1R+VUK=&UP9&ER+F,*(R!4:&ES(&-O9&4@86QS;R!L:79E<R!I;B!005(Z
M.E-E='5P5&5M<"!A<R!S971?<&%R7W1E;7!?96YV(0IS=6(@7W-E=%]P87)?
M=&5M<"!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!A<E]T96UP(#T@
M)#$["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A
M=&@@*`H@("`@("`@("AM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-
M4$1)4B!414U01$E2(%1%35`@5$U0("DI+`H@("`@("`@('%W*"!#.EQ<5$5-
M4"`O=&UP("X@*0H@("`@*2!["B`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE
M9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PH@("`@("`@(&UY
M("1U<V5R;F%M93L*("`@("`@("!M>2`D<'=U:60["B`@("`@("`@(R!D;V5S
M(&YO="!W;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PH*("`@("`@("!I9B`H
M(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PH@("`@("`@("`@("`D
M=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*("`@("`@("!]"B`@("`@
M("`@96QS:68@*&1E9FEN960@)'!W=6ED*2!["B`@("`@("`@("`@("1U<V5R
M;F%M92`]("1P=W5I9#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@
M("`@("`@("1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%
M4GT@?'P@)U-94U1%32<["B`@("`@("`@?0H@("`@("`@("1U<V5R;F%M92`]
M?B!S+UQ7+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N
M9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*("`@
M("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!I9B`H(21%3E9[
M4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;
M.5TI('L*("`@("`@("`@("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M
M92D["B`@("`@("`@("`@('-E96L@)&9H+"`M,3@L(#(["B`@("`@("`@("`@
M('-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@("`@("`@("`@("!I9B`H)&)U
M9B!E<2`B7#!#04-(12(I('L*("`@("`@("`@("`@("`@('-E96L@)&9H+"`M
M-3@L(#(["B`@("`@("`@("`@("`@("!S>7-R96%D("1F:"P@)&)U9BP@-#$[
M"B`@("`@("`@("`@("`@("`D8G5F(#U^(',O7#`O+V<["B`@("`@("`@("`@
M("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B
M=68["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@
M("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[
M($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("`@("`@("`@('Q\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN
M97<@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@("`@("`@
M("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A
M;F0@-2XS.0H@("`@("`@("`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A
M;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@("`@
M("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I
M;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D
M9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C
M='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q.PH@("`@("`@("`@("`D
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["B`@("`@("`@
M?0H*("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PH@("`@("`@
M(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&QA<W0["B`@("!]"@H@
M("`@)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+SL*?0H*<W5B(%]T96UP9FEL92!["B`@("!M
M>2`H)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY("@D9F@L("1F:6QE;F%M92D[
M"@H@("`@)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["@H@("`@
M:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@("`@('5N;&EN:R`D9FEL96YA
M;64@:68@+64@)&9I;&5N86UE.PH@("`@("`@('!U<V@@0'1M<&9I;&4L("1F
M:6QE;F%M93L*("`@('T*("`@(&5L<V4@>PH@("`@("`@(')E='5R;B`H=6YD
M968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["B`@("!]"@H@("`@
M;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@(&)I;FUO
M9&4H)&9H*3L*("`@(')E='5R;B@D9F@L("1F:6QE;F%M92D["GT*"B,@<V%M
M92!C;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G;F%M93HZ<V5T7W!R;V=N
M86UE"G-U8B!?<V5T7W!R;V=N86UE('L*("`@(&EF("AD969I;F5D("1%3E9[
M4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI
M+RD@>PH@("`@("`@("1P<F]G;F%M92`]("0Q.PH@("`@?0H*("`@("1P<F]G
M;F%M92!\?#T@)#`["@H@("`@:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E
M>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B`@("`@("`@
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@?0H*("`@(&EF("@A)$5.
M5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`^/2`P*2!["B`@("`@("`@:68@*&]P96X@;7D@)&9H+"`G/"<L
M("1P<F]G;F%M92D@>PH@("`@("`@("`@("!R971U<FX@:68@+7,@)&9H.PH@
M("`@("`@('T*("`@("`@("!I9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2!["B`@("`@("`@("`@("1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5]
M.PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@?0H*("`@(&9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L
M("1%3E9[4$%42'TI('L*("`@("`@("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!
M4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*("`@("`@("`D
M9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*("`@("`@("`H*"1P
M<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PH@("`@("`@("@H
M)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@
M;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P<F]G;F%M92!["B`@("`D
M,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PH@("`@:68@
M*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@
M("`@("`D<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92([
M"B`@("!]"@H@("`@(R!86%@@+2!H86-K('1O(&UA:V4@4%=$('=O<FL*("`@
M(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C
M=V0H*0H@("`@("`@("`@("`@("`@.B`H*&1E9FEN960@)E=I;C,R.CI'971#
M=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W
M9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E
M;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R7VEN:71?96YV('L*
M("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*("`@
M("`@("!R971U<FX["B`@("!](&5L<V4@>PH@("`@("`@("1%3E9[4$%27TE.
M251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!4
M14U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@
M*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1??3L*("`@('T*("`@
M(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*("`@("`@
M("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF
M(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@("`@?0H*("`@(&UY
M("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@("`@("`@(&1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I9B`H(65X:7-T<R`D
M14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@)'9A;'5E(#T@
M<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*("`@
M("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?
M0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@("!R971U<FX@
M:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@("`@('!R:6YT("1L
M;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@("`@("!P<FEN="`B
M0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@("!R97%U:7)E($-O
M;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI8F5X<"!P<FEV;&EB
M97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@("!V96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U
M=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.
M0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PH*
M9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N
M86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S
M("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@
M:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`
M.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*0T]213HZ97AI="@D
M,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L:6YE(#$P,3$*
M"E]?14Y$7U\*````````````````````P$,!&P,[U````!D```#8;/__\```
M`.AM__\8`0``*&[__S`!```8A/__8`$``/B$__^(`0``2(7__Z@!``!HA?__
MP`$``+B%___8`0``V(7___`!``"HAO__"`(``/B'__\H`@``2(C__T@"``!8
MBO__@`(``'B+__^X`@``.(W__]`"``!HC?__Z`(``%B.__\(`P``R([__R`#
M``"XD/__0`,``&B2__]X`P``F)S__[`#``!HG?__T`,``'B=___H`P``6*#_
M_P@$``!XH/__(`0````````4``````````%Z4@`!>!`!`PP'")`!```D````
M'````#`?0`"<`````$$.$(8"0PT&0HT#2X,%C`0`````````%````$0```!`
M($``-```````````````+````%P```"`($``\!4```!"#A!&#AA"#B!!#BB&
M!8P$C0..`D0.,$<.N`2#!@``)````(P```!P-D``V0````!*CP*,!5X.0(X#
MC02&!H,'`````````!P```"T````4#=``$\`````00X000X8@P.&`D<.,```
M%````-0```"@-T``%0````!$#B``````%````.P```#`-T``30````!$#A``
M````%`````0!```0.$``'@````!$#A``````%````!P!```P.$``P@````!(
M#A"#`@``'````#0!````.4``0@$```!*@P:,!%D.L`&.`HT#A@4<````5`$`
M`%`Z0`!/`````$$.$(,"1PZ0`0```````#0```!T`0``H#I```4"````0@X0
M1`X8C@./`D4.($(.*$$.,(8&C`6-!$0..$0.4(,'````````-````*P!``"P
M/$``%P$```!"#A!"#AB.`X\"10X@0@XHC`6-!$<.,$$..$0.@`&#!X8&````
M```4````Y`$``-`]0`"^`0```$0.0``````4````_`$``)`_0``B`````$0.
M$``````<````%`(``,`_0`#B`````$$.$$$.&(,#A@)'#B```!0````T`@``
ML$!``&T`````3@X@A@*#`QP```!,`@``($%``/`!````00X01`XP@P(`````
M````-````&P"```00T``K`$```!"#A!"#AA"#B!"#BB,!8T$C@./`DD.,$$.
M.(,'A@9*#N`)```````T````I`(``,!$0``L"@```$(.$(\"2@X80@X@0@XH
M00XP00XX1PZ@A`*#!X8&C`6-!(X#`````!P```#<`@``\$Y``,D`````5@[`
M$(P"A@.#!```````%````/P"``#`3T``!0``````````````'````!0#``#0
M3T``W`(```!"#A!/#AA!#B"#!(8#C`(4````-`,``+!20``4````````````
M```4````3`,``-!20``G`````$0.$```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````__________\``````````/__________````````````
M``````````$``````````0`````````!`````````/X!`````````0``````
M```(`@````````$`````````%@(````````!`````````","`````````0``
M``````!'`@````````\`````````<`,````````,`````````$`;0```````
M#0`````````T4T````````0`````````,`)````````%`````````+`.0```
M````!@````````!0!4````````H`````````E`0````````+`````````!@`
M````````%0````````````````````,`````````&,)@```````"````````
M`*`%````````%``````````'`````````!<`````````H!5````````'````
M`````%`40```````"`````````!0`0````````D`````````&`````````#^
M__]O`````!`40```````____;P`````"`````````/#__V\`````1!-`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````HP&````````````````````````````!J&T```````'H;0```
M````BAM```````":&T```````*H;0```````NAM```````#*&T```````-H;
M0```````ZAM```````#Z&T````````H<0```````&AQ````````J'$``````
M`#H<0```````2AQ```````!:'$```````&H<0```````>AQ```````"*'$``
M`````)H<0```````JAQ```````"Z'$```````,H<0```````VAQ```````#J
M'$```````/H<0```````"AU````````:'4```````"H=0```````.AU`````
M``!*'4```````%H=0```````:AU```````!Z'4```````(H=0```````FAU`
M``````"J'4```````+H=0```````RAU```````#:'4```````.H=0```````
M^AU````````*'D```````!H>0```````*AY````````Z'D```````$H>0```
M````6AY```````!J'D```````'H>0```````BAY```````":'D```````*H>
M0```````NAY```````#*'D```````-H>0```````ZAY```````#Z'D``````
M``H?0```````&A]```````#F5$``````````````````&,!@``````"85D``
M`````/____\`)$9R965"4T0Z(')E;&5N9R\Y+C$O;&EB+V-S=2]A;60V-"]C
M<G0Q+F,@,C$V,S,X(#(P,3`M,3(M,#D@,C$Z,S$Z,C%:(&1I;2`D`"1&<F5E
M0E-$.B!R96QE;F<O.2XQ+VQI8B]C<W4O8V]M;6]N+V-R=&)R86YD+F,@,C$W
M,S<U(#(P,3$M,#$M,3,@,C`Z-#0Z,S%:(&1I;2`D`$=#0SH@*$=.52D@-"XR
M+C$@,C`P-S`X,S$@<&%T8VAE9"!;1G)E94)31%T``"1&<F5E0E-$.B!R96QE
M;F<O.2XQ+VQI8B]C<W4O86UD-C0O8W)T:2Y3(#(Q-S$P-2`R,#$Q+3`Q+3`W
M(#$V.C`W.C4Q6B!K:6(@)```1T-#.B`H1TY5*2`T+C(N,2`R,#`W,#@S,2!P
M871C:&5D(%M&<F5E0E-$70``1T-#.B`H1TY5*2`T+C(N,2`R,#`W,#@S,2!P
M871C:&5D(%M&<F5E0E-$70``1T-#.B`H1TY5*2`T+C(N,2`R,#`W,#@S,2!P
M871C:&5D(%M&<F5E0E-$70``)$9R965"4T0Z(')E;&5N9R\Y+C$O;&EB+V-S
M=2]A;60V-"]C<G1N+E,@,C$W,3`U(#(P,3$M,#$M,#<@,38Z,#<Z-3%:(&MI
M8B`D```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E
M;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE
M:%]F<F%M95]H9'(`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N9'EN
M86UI8P`N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM96YT````````````````
M````````````````````````````````````````````````````````````
M````````````````````"P````$````"```````````"0`````````(`````
M```5`````````````````````0```````````````````!,````'`````@``
M```````8`D```````!@"````````&`````````````````````0`````````
M```````````A````!0````(`````````,`)````````P`@```````!P#````
M````!``````````(``````````0`````````)P````L````"`````````%`%
M0```````4`4```````!@"0````````4````!````"``````````8````````
M`"\````#`````@````````"P#D```````+`.````````E`0`````````````
M``````$````````````````````W````____;P(`````````1!-```````!$
M$P```````,@`````````!``````````"``````````(`````````1````/[_
M_V\"`````````!`40```````$!0```````!```````````4````"````"```
M`````````````````%,````$`````@````````!0%$```````%`4````````
M4`$````````$``````````@`````````&`````````!=````!`````(`````
M````H!5```````"@%0```````*`%````````!`````L````(`````````!@`
M````````9P````$````&`````````$`;0```````0!L````````3````````
M````````````!````````````````````&(````!````!@````````!4&T``
M`````%0;````````T`,```````````````````0`````````$`````````!M
M`````0````8`````````,!]````````P'P````````0T````````````````
M```0````````````````````<P````$````&`````````#130```````-%,`
M```````.````````````````````!````````````````````'D````!````
M`@````````!(4T```````$A3````````$%\```````````````````@`````
M``````````````"!`````0````(`````````6+)```````!8L@```````-0`
M```````````````````$````````````````````CP````$````"````````
M`#"S0```````,+,```````!D`P``````````````````"```````````````
M`````)D````!`````P``````````P&````````#`````````$```````````
M``````````@```````````````````"@`````0````,`````````$,!@````
M```0P````````!`````````````````````(````````````````````IP``
M``$````#`````````"#`8```````(,`````````(````````````````````
M"````````````````````*P````&`````P`````````HP&```````"C`````
M````\`$````````%``````````@`````````$`````````"U`````0````,`
M````````&,)@```````8P@```````/@!```````````````````(````````
M``@`````````O@````$````#`````````!#$8```````$,0````````D````
M````````````````"````````````````````,0````(`````P````````!`
MQ&```````#3$````````2`4``````````````````"``````````````````
M``#)`````0`````````````````````````TQ````````.L!````````````
M```````!`````````````````````0````,`````````````````````````
H'\8```````#2`````````````````````0``````````````````````
